@@ -1,4 +1,3 @@
-import base64
 import hashlib
 from Crypto import Random
 from Crypto.Cipher import AES
@@ -11,17 +10,17 @@ __ALL__ = ["AESCipher"]
 class AESCipher(object):
     def __init__(self, key: str_or_bytes) -> None:
         if isinstance(key, str):
-            key = key.encode("utf-8")
+            key = utf8e(key)
         self.key = hashlib.sha256(key).digest()
 
     def encrypt(self, raw: str_or_bytes) -> str:
         raw = _pad(raw)
         iv = Random.new().read(AES.block_size)
         cipher = AES.new(self.key, AES.MODE_CBC, iv)
-        return base64.b64encode(iv + cipher.encrypt(raw)).decode("utf-8")
+        return b64e(iv + cipher.encrypt(raw))
 
     def decrypt(self, enc: str) -> str_or_bytes:
-        enc = base64.b64decode(enc)
+        enc = b64d(enc)
         iv = enc[:AES.block_size]
         cipher = AES.new(self.key, AES.MODE_CBC, iv)
         return _unpad(cipher.decrypt(enc[AES.block_size:]))
@@ -35,16 +34,11 @@ def _pad(s: str_or_bytes) -> bytes:
     else:
         char = chr(gap)
     s = s + char * gap
-    if isinstance(s, str):
-        return s.encode("utf-8")
-    return s
+    return try_utf8e(s)
 
 
 def _unpad(s: str_or_bytes) -> str_or_bytes:
     s = s[:-ord(s[len(s)-1:])]
-    try:
-        return s.decode("utf-8")
-    except UnicodeDecodeError:
-        return s
+    return try_utf8d(s)
 
 
